==> pre_commit_mirror_maker-1.1.0-py2.py3-none-any.whl: pre_commit_mirror_maker/languages.py <==
import json
import subprocess
import urllib.request
from typing import List

from packaging import version


def ruby_get_package_versions(package_name: str) -> List[str]:
    url = f'https://rubygems.org/api/v1/versions/{package_name}.json'
    resp = json.loads(urllib.request.urlopen(url).read())
    return list(reversed([version['number'] for version in resp]))


def node_get_package_versions(package_name: str) -> List[str]:
    cmd = ('npm', 'view', package_name, '--json')
    output = json.loads(subprocess.check_output(cmd))
    return output['versions']


def python_get_package_versions(package_name: str) -> List[str]:
    url = f'https://pypi.org/pypi/{package_name}/json'
    resp = json.loads(urllib.request.urlopen(url).read())
    return sorted(resp['releases'], key=lambda k: version.parse(k))


def rust_get_package_versions(package_name: str) -> List[str]:
    url = f'https://crates.io/api/v1/crates/{package_name}'
    resp = json.loads(urllib.request.urlopen(url).read())
    return list(reversed([version['num'] for version in resp['versions']]))


def node_get_additional_dependencies(
        package_name: str, package_version: str,
) -> List[str]:
    return [f'{package_name}@{package_version}']


def rust_get_additional_dependencies(
        package_name: str, package_version: str,
) -> List[str]:
    return [f'cli:{package_name}:{package_version}']


LIST_VERSIONS = {
    'node': node_get_package_versions,
    'python': python_get_package_versions,
    'ruby': ruby_get_package_versions,
    'rust': rust_get_package_versions,
}

ADDITIONAL_DEPENDENCIES = {
    'node': node_get_additional_dependencies,
    'rust': rust_get_additional_dependencies,
}

==> pre_commit_mirror_maker-1.6.0-py2.py3-none-any.whl: pre_commit_mirror_maker/languages.py <==
import json
import subprocess
import urllib.request
from typing import List

from packaging import version


def ruby_get_package_versions(package_name: str) -> List[str]:
    url = f'https://rubygems.org/api/v1/versions/{package_name}.json'
    resp = json.load(urllib.request.urlopen(url))
    return list(reversed([version['number'] for version in resp]))


def node_get_package_versions(package_name: str) -> List[str]:
    cmd = ('npm', 'view', package_name, '--json')
    output = json.loads(subprocess.check_output(cmd))
    return output['versions']


def python_get_package_versions(package_name: str) -> List[str]:
    url = f'https://pypi.org/pypi/{package_name}/json'
    resp = json.load(urllib.request.urlopen(url))
    return sorted(resp['releases'], key=lambda k: version.parse(k))


def rust_get_package_versions(package_name: str) -> List[str]:
    url = f'https://crates.io/api/v1/crates/{package_name}'
    resp = json.load(urllib.request.urlopen(url))
    return list(reversed([version['num'] for version in resp['versions']]))


def node_get_additional_dependencies(
        package_name: str, package_version: str,
) -> List[str]:
    return [f'{package_name}@{package_version}']


def rust_get_additional_dependencies(
        package_name: str, package_version: str,
) -> List[str]:
    return [f'cli:{package_name}:{package_version}']


LIST_VERSIONS = {
    'node': node_get_package_versions,
    'python': python_get_package_versions,
    'ruby': ruby_get_package_versions,
    'rust': rust_get_package_versions,
}

ADDITIONAL_DEPENDENCIES = {
    'node': node_get_additional_dependencies,
    'rust': rust_get_additional_dependencies,
}
